==> editics-1.0.1.tar.gz: editics/modules/cri_php_word/src/TemplateProcessor.php <==
<?php
namespace Drupal\cri_php_word;

use PhpOffice\PhpWord\Exception\CopyFileException;
use PhpOffice\PhpWord\Exception\CreateTemporaryFileException;
use PhpOffice\PhpWord\TemplateProcessor as Base;

class TemplateProcessor extends Base
{
  /**
   * TemplateProcessor constructor.
   * @param $documentTemplate
   * @throws CopyFileException
   * @throws CreateTemporaryFileException
   */
  public function __construct($documentTemplate)
  {
    parent::__construct($documentTemplate);
  }

  public function makeWord($item) {
    if (!empty($item->type)) {
      $className = 'Drupal\cri_php_word\elements\\' . ucfirst($item->type);
      if (class_exists($className)) {
        $class = new $className();
        if (method_exists($class, 'process')) {
          return $class->process($this, $item);
        }else {
          return ['errorCode' => 101, 'message' => 'process method not found!'];
        }
      }else {
        return ['errorCode' => 202, 'message' => $item->type . ' class not found!'];
      }
    }
  }

  /**
   * Return reals variables in the model
   * @return array
   */
  public function getVariableCountParts() {
    $variables = $this->getVariablesForPart($this->tempDocumentMainPart);
    $tmpVariables = [];
    foreach ($this->tempDocumentHeaders as $headerXML) {
      $tmpVariables = array_merge(
        $tmpVariables,
        $this->getVariablesForPart($headerXML)
      );
    }

    foreach ($this->tempDocumentFooters as $footerXML) {
      $tmpVariables = array_merge(
        $tmpVariables,
        $this->getVariablesForPart($footerXML)
      );
    }
    $tmpVariables = array_unique($tmpVariables);
    return array_count_values(array_merge($variables, $tmpVariables));
  }
}

==> editics-1.0.6.tar.gz: editics/modules/cri_php_word/src/TemplateProcessor.php <==
<?php
namespace Drupal\cri_php_word;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use PhpOffice\PhpWord\Exception\CopyFileException;
use PhpOffice\PhpWord\Exception\CreateTemporaryFileException;
use PhpOffice\PhpWord\TemplateProcessor as Base;

class TemplateProcessor extends Base
{
  use StringTranslationTrait;
  /**
   * TemplateProcessor constructor.
   * @param $documentTemplate
   * @throws CopyFileException
   * @throws CreateTemporaryFileException
   */
  public function __construct($documentTemplate)
  {
    parent::__construct($documentTemplate);
  }

  public function makeWord($item) {
    if (!empty($item->type)) {
      $className = 'Drupal\cri_php_word\elements\\' . ucfirst($item->type);
      if (class_exists($className)) {
        $class = new $className();
        if (method_exists($class, 'process')) {
          return $class->process($this, $item);
        }else {
          return ['errorCode' => 101, 'message' => $this->t('process method not found!')];
        }
      }else {
        return ['errorCode' => 202, 'message' => $this->t('@type type not found!', ['@type' => $item->type])];
      }
    }
  }

  /**
   * Return reals variables in the model
   * @return array
   */
  public function getVariableCountParts() {
    $variables = $this->getVariablesForPart($this->tempDocumentMainPart);
    $tmpVariables = [];
    foreach ($this->tempDocumentHeaders as $headerXML) {
      $tmpVariables = array_merge(
        $tmpVariables,
        $this->getVariablesForPart($headerXML)
      );
    }

    foreach ($this->tempDocumentFooters as $footerXML) {
      $tmpVariables = array_merge(
        $tmpVariables,
        $this->getVariablesForPart($footerXML)
      );
    }
    $tmpVariables = array_unique($tmpVariables);
    return array_count_values(array_merge($variables, $tmpVariables));
  }
}
